@@ -7,6 +7,11 @@ from connect.autogen import connect_models_Agreement as Agreement
 from connect.autogen import connect_models_AgreementStats as AgreementStats
 from connect.autogen import connect_models_Asset as Asset
 from connect.autogen import connect_models_AssetRequest as AssetRequest
+from connect.autogen import connect_models_BillingAnniversary as BillingAnniversary
+from connect.autogen import connect_models_BillingInfo as BillingInfo
+from connect.autogen import connect_models_BillingStats as BillingStats
+from connect.autogen import connect_models_BillingStatsInfo as BillingStatsInfo
+from connect.autogen import connect_models_BillingStatsRequest as BillingStatsRequest
 from connect.autogen import connect_models_Category as Category
 from connect.autogen import connect_models_Choice as Choice
 from connect.autogen import connect_models_Configuration as Configuration
@@ -29,6 +34,7 @@ from connect.autogen import connect_models_Hub as Hub
 from connect.autogen import connect_models_HubStats as HubStats
 from connect.autogen import connect_models_Instance as Instance
 from connect.autogen import connect_models_Item as Item
+from connect.autogen import connect_models_ItemBilling as ItemBilling
 from connect.autogen import connect_models_Listing as Listing
 from connect.autogen import connect_models_ListingRequest as ListingRequest
 from connect.autogen import connect_models_ListingSourcing as ListingSourcing
@@ -43,12 +49,17 @@ from connect.autogen import connect_models_ProductConfigurationParam as ProductC
 from connect.autogen import connect_models_ProductStats as ProductStats
 from connect.autogen import connect_models_ProductStatsInfo as ProductStatsInfo
 from connect.autogen import connect_models_Renewal as Renewal
+from connect.autogen import connect_models_Subscription as Subscription
+from connect.autogen import connect_models_SubscriptionRequest as SubscriptionRequest
+from connect.autogen import connect_models_SubscriptionRequestAttributes as SubscriptionRequestAttributes
 from connect.autogen import connect_models_Template as Template
 from connect.autogen import connect_models_TierAccount as TierAccount
 from connect.autogen import connect_models_TierConfig as TierConfig
 from connect.autogen import connect_models_TierConfigRequest as TierConfigRequest
 from connect.autogen import connect_models_Tiers as Tiers
+from connect.autogen import connect_models_UsageCategory as UsageCategory
 from connect.autogen import connect_models_UsageFile as UsageFile
+from connect.autogen import connect_models_UsageParam as UsageParam
 from connect.autogen import connect_models_UsageRecord as UsageRecord
 from connect.autogen import connect_models_UsageStats as UsageStats
 from connect.autogen import connect_models_User as User
@@ -64,6 +75,11 @@ __all__ = [
     'AgreementStats',
     'Asset',
     'AssetRequest',
+    'BillingAnniversary',
+    'BillingInfo',
+    'BillingStats',
+    'BillingStatsInfo',
+    'BillingStatsRequest',
     'Category',
     'Choice',
     'Configuration',
@@ -86,6 +102,7 @@ __all__ = [
     'HubStats',
     'Instance',
     'Item',
+    'ItemBilling',
     'Listing',
     'ListingRequest',
     'ListingSourcing',
@@ -100,12 +117,17 @@ __all__ = [
     'ProductStats',
     'ProductStatsInfo',
     'Renewal',
+    'Subscription',
+    'SubscriptionRequest',
+    'SubscriptionRequestAttributes',
     'Template',
     'TierAccount',
     'TierConfig',
     'TierConfigRequest',
     'Tiers',
+    'UsageCategory',
     'UsageFile',
+    'UsageParam',
     'UsageRecord',
     'UsageStats',
     'User',
